![image](documents/graphics/naust_banner.png)

Collection of various Python functions, templates etc for working with oceanography data specific to the [Norwegian Polar Institute](https://www.npolar.no/en/) (NPI).

The idea is more in-house specific things can live here, but more truly general stuff can live in [kval](github.com/NPIOcean/kval).

Example of things to put here:

- Parsers for specific file formats.
- NPI-specific metadata fixing.
- Salinity QC.
- Log sheets, excel sheets and associated parsers or converterts.
____

**USAGE EXAMPLES**

- [QC of CTD salinity against salinometer values](notebooks/examples/salts/Salt_QC_example.ipynb)

____

Maintained by the Oceanography section at NPI.

____

Most recent release: *v0.1.2*




[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.17356730.svg)](https://doi.org/10.5281/zenodo.17356730)



